@@ -4,42 +4,36 @@ from orionis.test.cases.asynchronous import AsyncTestCase
 
 class TestFoundationConfigRootPaths(AsyncTestCase):
     """
-    Test suite for the Paths dataclass which defines the project directory structure.
+    Test suite for the `Paths` dataclass, which defines the project directory structure.
 
-    This class verifies the integrity of path definitions, default values,
-    and the behavior of accessor methods.
-
-    Methods
-    -------
-    testDefaultPathsInstantiation()
-        Test that a Paths instance can be created with default values.
-    testAllPathsAreStrings()
-        Test that all path attributes are strings.
-    testPathValidationRejectsNonStringValues()
-        Test that non-string path values raise OrionisIntegrityException.
-    testToDictReturnsCompleteDictionary()
-        Test that toDict() returns a complete dictionary of all paths.
-    testFrozenDataclassBehavior()
-        Test that the dataclass is truly frozen (immutable).
-    testPathMetadataIsAccessible()
-        Test that path metadata is properly defined and accessible.
+    This class contains asynchronous unit tests to verify the integrity, default values,
+    type constraints, immutability, and metadata accessibility of the `Paths` dataclass.
     """
 
     def testDefaultPathsInstantiation(self):
         """
-        Test that a Paths instance can be created with default values.
+        Test instantiation of `Paths` with default values.
 
-        Ensures that all default paths are correctly initialized and
-        the instance is properly constructed.
+        Ensures that a `Paths` instance can be created using default arguments and
+        that the resulting object is an instance of `Paths`.
+
+        Returns
+        -------
+        None
         """
         paths = Paths()
         self.assertIsInstance(paths, Paths)
 
     def testAllPathsAreStrings(self):
         """
-        Test that all path attributes are strings.
+        Verify that all attributes of `Paths` are strings.
 
-        Ensures that every field in Paths is a string by default.
+        Iterates through all fields of the `Paths` dataclass and asserts that each
+        attribute is a non-empty string.
+
+        Returns
+        -------
+        None
         """
         paths = Paths()
         for field_name in paths.__dataclass_fields__:
@@ -49,25 +43,24 @@ class TestFoundationConfigRootPaths(AsyncTestCase):
 
     def testPathValidationRejectsNonStringValues(self):
         """
-        Test that non-string path values raise OrionisIntegrityException.
+        Ensure non-string path values raise `OrionisIntegrityException`.
 
-        Verifies that the __post_init__ validation rejects non-string values
-        for all path fields.
+        Attempts to instantiate `Paths` with a non-string value for a path field
+        and asserts that an `OrionisIntegrityException` is raised.
 
-        Raises
-        ------
-        OrionisIntegrityException
-            If a non-string value is provided.
+        Returns
+        -------
+        None
         """
         with self.assertRaises(OrionisIntegrityException):
             Paths(console_scheduler=123)
 
     def testToDictReturnsCompleteDictionary(self):
         """
-        Test that toDict() returns a complete dictionary of all paths.
+        Test that `toDict()` returns a complete dictionary of all path fields.
 
-        Verifies that the returned dictionary contains all path fields
-        with their current values.
+        Asserts that the dictionary returned by `toDict()` contains all fields
+        defined in the `Paths` dataclass and that the dictionary has the correct length.
 
         Returns
         -------
@@ -82,15 +75,14 @@ class TestFoundationConfigRootPaths(AsyncTestCase):
 
     def testFrozenDataclassBehavior(self):
         """
-        Test that the dataclass is truly frozen (immutable).
+        Verify that the `Paths` dataclass is immutable (frozen).
 
-        Verifies that attempts to modify attributes after creation
-        raise exceptions.
+        Attempts to modify an attribute of a `Paths` instance after creation and
+        asserts that an exception is raised due to immutability.
 
-        Raises
-        ------
-        Exception
-            If an attempt is made to modify a frozen dataclass.
+        Returns
+        -------
+        None
         """
         paths = Paths()
         with self.assertRaises(Exception):
@@ -98,10 +90,11 @@ class TestFoundationConfigRootPaths(AsyncTestCase):
 
     def testPathMetadataIsAccessible(self):
         """
-        Test that path metadata is properly defined and accessible.
+        Check accessibility and structure of path field metadata.
 
-        Verifies that each path field has the expected metadata structure
-        with description and default fields.
+        Iterates through all fields of the `Paths` dataclass and asserts that each
+        field's metadata contains both 'description' and 'default' keys, and that
+        their values are of the expected types.
 
         Returns
         -------
